@@ -11,10 +11,9 @@ highest level.
 try:
     import vtk
 except ImportError, m: 
-    msg = '%s\n%s\nDo you have vtk installed properly?'%(m, '_'*80)
-    raise ImportError(msg)
-
-from os.path import splitext
+    m.args = ('%s\n%s\nDo you have vtk and its Python bindings installed properly?' %
+                    (m.args[0], '_'*80),)
+    raise 
 
 # Enthought library imports.
 from enthought.traits.api import (HasStrictTraits, List, Str, 
@@ -287,10 +286,9 @@ class Engine(HasStrictTraits):
         current scene or the passed `scene`.
         """
         passed_scene = scene
-        base, ext = splitext(filename)
-        readers = registry.get_file_reader(ext)
-        if len(readers) == 0:
-            msg = 'No readers found for the extension %s'%ext
+        reader = registry.get_file_reader(filename)        
+        if reader is None:
+            msg = 'No suitable reader found for the file %s'%filename
             error(msg)
         else:
             src = None
@@ -299,8 +297,9 @@ class Engine(HasStrictTraits):
             if scene is None:
                 scene = self.new_scene()
             try:
-                scene.scene.busy = True
-                reader = readers[-1]
+                sc = scene.scene
+                if sc is not None:
+                    sc.busy = True
                 callable = reader.get_callable()
                 if reader.factory is None:
                     src = callable()
@@ -312,7 +311,8 @@ class Engine(HasStrictTraits):
                 if src is not None:
                     self.add_source(src, passed_scene)
             finally:
-                scene.scene.busy = False
+                if sc is not None:
+                    sc.busy = False 
             if src is not None:
                 return src
 
@@ -344,14 +344,14 @@ class Engine(HasStrictTraits):
          name - `str` 
           The name assigned to the scene.  It tries to determine the
           name of the scene from the passed scene instance.  If this
-          is not possible it defaults to 'TVTK Scene'.
+          is not possible it defaults to 'Mayavi Scene'.
           
         """
         if name is None:
             if hasattr(scene, 'name'):
                 name = scene.name
             else:
-                name = 'TVTK Scene %d'%scene_id_generator.next()
+                name = 'Mayavi Scene %d'%scene_id_generator.next()
         
         s = Scene(scene=scene, name=name, parent=self)
         s.start()
