@@ -7,17 +7,19 @@
 
 
 from array_source import ArraySource
+from builtin_image import BuiltinImage
+from builtin_surface import BuiltinSurface
+from chaco_reader import ChacoReader
 from image_reader import ImageReader
 from parametric_surface import ParametricSurface
 from plot3d_reader import PLOT3DReader
 from point_load import PointLoad
+from poly_data_reader import PolyDataReader
 from three_ds_importer import ThreeDSImporter
 from vrml_importer import VRMLImporter
+from volume_reader import VolumeReader
 from vtk_data_source import VTKDataSource
 from vtk_file_reader import VTKFileReader
 from vtk_xml_file_reader import VTKXMLFileReader
-from poly_data_reader import PolyDataReader
 from unstructured_grid_reader import UnstructuredGridReader
-from builtin_image import BuiltinImage
-from builtin_surface import BuiltinSurface
 
