@@ -132,6 +132,7 @@ class EngineManager(HasTraits):
         if not engine.running:
             warnings.warn('Engine is not running', stacklevel=2)
         self.current_engine = engine
+        registry.register_engine(engine)
 
 
     def new_engine(self):
@@ -141,10 +142,11 @@ class EngineManager(HasTraits):
         check_backend()
         if options.backend == 'envisage':
             from enthought.mayavi.plugins.app import Mayavi
-            m = Mayavi()
+            m = Mayavi(start_gui_event_loop=False)
             m.main()
             process_ui_events()
-            engine = m.script.engine
+            window = m.application.workbench.active_window
+            engine = window.get_service(Engine)
         elif options.backend == 'test':
             engine = NullEngine(name='Null Mlab Engine')
             engine.start()
@@ -169,7 +171,7 @@ class EngineManager(HasTraits):
             raise TypeError, "Figure not attached to a mayavi engine."
 
 
-    def show_engine(self, engine=None):
+    def show_engine(self, engine=None, rich_view=True):
         """ Show a dialog with the mayavi pipeline. This dialog allows to
             edit graphicaly the properties of the different objects on
             the scenes.
@@ -180,12 +182,18 @@ class EngineManager(HasTraits):
                                             options.backend == 'test':
             # FIXME: This should pop up the relevent envisage view
             pass
-        else:
+        elif rich_view:
             from enthought.mayavi.core.ui.engine_rich_view import \
                     EngineRichView
             scene = engine.current_scene
             view = EngineRichView(engine=engine)
             return view.scene_editing_view(scene=scene.scene)
+        else:
+            from enthought.mayavi.core.ui.engine_view import \
+                    EngineView
+            scene = engine.current_scene
+            view = EngineView(engine=engine)
+            return view.edit_traits()
 
 
 engine_manager = EngineManager()
