@@ -2,8 +2,8 @@
 Helper functions for mlab. These combine creation of the data sources,
 and applying the modules to them to make standard visualization
 operation. They should always return the module object created, for
-consistency, and because retrieving the data_source from a module object
-is possible via tools._find_data
+consistency, and because retrieving the vtk data source from a module object
+is possible via tools.get_vtk_src
 
 Each helper function should have a test function associated with it,
 both for testing and to ilustrate its use.
@@ -635,6 +635,10 @@ class Surf(Pipeline):
                         data centered on the center of the extent. If you
                         are using explicit extents, this is the best way
                         to control the vertical scale of your plots.
+
+                        If you want to control the extent (or range)
+                        of the surface object, rather than its scale,
+                        see the `extent` keyword argument.
                         """)
 
     mask = Array(help="boolean mask array to suppress some data points.")
@@ -675,7 +679,10 @@ class Surf(Pipeline):
                 except AttributeError:
                     xi, xf, yi, yf, _, _ = self.source.image_data.bounds
                     zi, zf = self.source.image_data.scalar_range
-                zf = 0.3*((xf - xi) + (yf - yi))
+                z0 = zf - zi
+                dz = 0.3*((xf - xi) + (yf - yi))
+                zi = z0 - 0.5*dz
+                zf = z0 + 0.5*dz
                 kwargs['extent'] = (xi, xf, yi, yf, zi, zf)
             kwargs['warp_scale'] = 1.
         self.store_kwargs(kwargs)
@@ -978,7 +985,7 @@ class BarChart(Pipeline):
         if not 'color' in kwargs:
             g.glyph.color_mode = 'color_by_scalar'
         if not 'scale_mode' in kwargs:
-            g.glyph.glyph.scale_mode = 'scale_by_vector_components'
+            g.glyph.scale_mode = 'scale_by_vector_components'
         g.glyph.glyph.clamping = False
         x, y, z = g.mlab_source.x, g.mlab_source.y, g.mlab_source.z
         scale_factor = g.glyph.glyph.scale_factor* \
