@@ -85,7 +85,9 @@ class DataModuleFactory(ModuleFactory):
     
     extent = CArray(shape=(6,),
                     help="""[xmin, xmax, ymin, ymax, zmin, zmax]
-                            Default is the x, y, z arrays extents.""", )
+                            Default is the x, y, z arrays extents. Use
+                            this to change the extent of the object
+                            created.""", )
 
     def _extent_changed(self):
         tools.set_extent(self._target, self.extent)
@@ -491,7 +493,7 @@ vector_cut_plane = make_function(VectorCutPlaneFactory)
 
 
 ##############################################################################
-class ContourGridPlaneFactory(ContourModuleFactory, CutPlaneFactory):
+class ContourGridPlaneFactory(ContourModuleFactory):
     """ Applies the ContourGridPlane mayavi module to the given data
         source (Mayavi source, or VTK dataset).
     """
@@ -538,8 +540,8 @@ class VolumeFactory(PipeFactory):
             from enthought.tvtk.util.ctf import PiecewiseFunction
             otf = PiecewiseFunction()
             otf.add_point(value, opacity)
-            self._target._otf = otf
-            self._target._volume_property.set_scalar_opacity(otf)
+            vol._otf = otf
+            vol._volume_property.set_scalar_opacity(otf)
 
     """
 
