@@ -253,6 +253,36 @@ class MGlyphSource(MlabSource):
         self.update()
 
 
+################################################################################
+# `MVerticalGlyphSource` class.
+################################################################################ 
+class MVerticalGlyphSource(MGlyphSource):
+    """
+    This class represents a vertical glyph data source for Mlab objects 
+    and allows the user to set the x, y, z, scalar attributes. The
+    vectors are created from the scalars to represent them in the
+    vertical direction.
+    """
+
+    def reset(self, **traits):
+        """Creates the dataset afresh or resets existing data source."""
+        if 'scalars' in traits:
+            s = traits['scalars']
+            if s is not None:
+                traits['u'] = traits['v'] = numpy.ones_like(s), 
+                traits['w'] = s
+        super(MVerticalGlyphSource, self).reset(**traits)
+
+
+    def _scalars_changed(self, s):
+        self.dataset.point_data.scalars = s
+        self.dataset.point_data.scalars.name = 'scalars'
+        self.set(vectors=numpy.c_[numpy.ones_like(s), 
+                                  numpy.ones_like(s),
+                                  s])
+        self.update()
+
+
 ################################################################################
 # `MArraySource` class.
 ################################################################################ 
@@ -435,7 +465,7 @@ class MLineSource(MlabSource):
 
         if scalars is not None and len(scalars) > 0:
             assert len(x) == len(scalars)
-            pd.point_data.scalars = scalars.ravel() 
+            pd.point_data.scalars = numpy.ravel(scalars)
             pd.point_data.scalars.name = 'scalars'
 
         self.dataset = pd
@@ -904,7 +934,7 @@ def vector_scatter(*args, **kwargs):
 
     scalars = kwargs.pop('scalars', None)
     if scalars is not None:
-        scalars = scalars.ravel()
+        scalars = numpy.ravel(scalars)
     name = kwargs.pop('name', 'VectorScatter')
 
     data_source = MGlyphSource()
@@ -992,7 +1022,7 @@ def scalar_scatter(*args, **kwargs):
     x, y, z, s = process_regular_scalars(*args)
 
     if s is not None:
-        s = s.ravel()
+        s = numpy.ravel(s)
 
     data_source = MGlyphSource()
     data_source.reset(x=x, y=y, z=z, scalars=s)
@@ -1223,15 +1253,18 @@ def vertical_vectors_source(*args, **kwargs):
             z = numpy.zeros_like(x)
         args = (x, y, z, data)
 
-    # Tranform the signature from a scalar_scatter-like one to a 
-    # vector_scatter-like one.
     x, y, z, s = process_regular_scalars(*args)
-    args = (x, y, z, numpy.ones_like(s), numpy.ones_like(s), s)
-    kwargs['scalars'] = s
-    if not 'name' in kwargs:
-        kwargs['name'] = 'VerticalVectorsSource'
-    return vector_scatter(*args, **kwargs)
 
+    if s is not None:
+        s = numpy.ravel(s)
+
+    data_source = MVerticalGlyphSource()
+    data_source.reset(x=x, y=y, z=z, scalars=s)
+
+    name = kwargs.pop('name', 'VerticalVectorsSource')
+    ds = tools.add_dataset(data_source.dataset, name, **kwargs)
+    data_source.m_data = ds
+    return ds
 
 def triangular_mesh_source(x, y, z, triangles, **kwargs):
     """
