@@ -8,6 +8,7 @@ The general purpose tools to manipulate the pipeline with the mlab interface.
 
 # Standard library imports.
 import numpy
+import types
 
 # Enthought library imports.
 from enthought.tvtk.api import tvtk
@@ -15,8 +16,8 @@ from enthought.tvtk.api import tvtk
 # MayaVi related imports.
 from enthought.mayavi.sources.vtk_data_source import VTKDataSource
 from enthought.mayavi.core.module_manager import ModuleManager
-from enthought.mayavi.sources.array_source import ArraySource
 from enthought.mayavi.core.source import Source
+from enthought.mayavi.core.filter import Filter
 
 from engine_manager import get_engine, engine_manager, get_null_engine
 from figure import gcf
@@ -105,37 +106,44 @@ def _traverse(node):
         pass
     yield node
 
-def _find_data(object):
-    """Goes up the vtk pipeline to find the data sources of a given
-    object.
+def get_vtk_src(mayavi_object, stop_at_filter=True):
+    """ Goes up the Mayavi pipeline to find the data sources of a given
+        object.
+
+        **Parameters**
+    
+        :object: any Mayavi visualization object
+       
+        :stop_at_filter: optional boolean flag: if True, the first object
+                         exposing data found going up the pipeline is
+                         returned. If False, only the source itself
+                         is returned.
+
+        **Returns**
+
+        :sources: List of vtk data sources (vtk data sources, and not
+                  Mayavi source objects).
+
+        **Notes**
+
+        This function traverses the Mayavi pipeline. Thus the input
+        object 'mayavi_object' should already be added to the pipeline.
     """
-    if isinstance(object, ModuleManager):
-        inputs = [object.source]
-    elif hasattr(object, 'module_manager'):
-        inputs = [object.module_manager.source]
-    elif ( hasattr(object, 'data') or isinstance(object, ArraySource) 
-                or hasattr(object, 'inputs')):
-        inputs = [object]
-    else:
-        raise TypeError, 'Cannot find data source for given object'
-    data_sources = []
-    try:
-        while True:
-            input = inputs.pop()
-            if hasattr(input, 'inputs'):
-                inputs += input.inputs
-            elif hasattr(input, 'image_data'):
-                data_sources.append(input.image_data)
-            else:
-                data_sources.append(input.data)
-    except IndexError:
-        pass
-    return data_sources
+    if not (   hasattr(mayavi_object, 'parent') 
+            or isinstance(mayavi_object, Source)):
+        raise TypeError, 'Cannot find data source for given object %s' % (
+                                            mayavi_object)
+    while True:
+        # XXX: If the pipeline is not a DAG, this is an infinite loop
+        if isinstance(mayavi_object, Source):
+            if stop_at_filter or not isinstance(mayavi_object, Filter):
+                return mayavi_object.outputs
+        mayavi_object = mayavi_object.parent
 
 def _has_scalar_data(object):
     """Tests if an object has scalar data.
     """
-    data_sources = _find_data(object)
+    data_sources = get_vtk_src(object)
     for source in data_sources:
         if source.point_data.scalars is not None:
             return True
@@ -146,7 +154,7 @@ def _has_scalar_data(object):
 def _has_vector_data(object):
     """Tests if an object has vector data.
     """
-    data_sources = _find_data(object)
+    data_sources = get_vtk_src(object)
     for source in data_sources:
         if source.point_data.vectors is not None:
             return True
@@ -157,7 +165,7 @@ def _has_vector_data(object):
 def _has_tensor_data(object):
     """Tests if an object has tensor data.
     """
-    data_sources = _find_data(object)
+    data_sources = get_vtk_src(object)
     for source in data_sources:
         if source.point_data.tensors is not None:
             return True
@@ -299,3 +307,39 @@ def set_extent(module, extents):
                                             zpos + zo -zcenter)
 
 
+def start_recording(ui=True):
+    """Start automatic script recording.  If the `ui` parameter is
+    `True`, it creates a recorder with a user interface, if not it
+    creates a vanilla recorder without a UI.
+
+    **Returns**
+        The `Recorder` instance created.
+    """
+    from enthought.scripting.api import start_recording as start
+    e = get_engine()
+    msg = "Current engine, %s, is already being recorded."%(e)
+    assert e.recorder is None, msg
+    r = start(e, ui=ui)
+    return r
+
+def stop_recording(file=None):
+    """Stop the automatic script recording.
+
+    **Parameters**
+
+     :file: An open file or a filename or `None`.  If this is `None`,
+            nothing is saved.
+
+    """
+    from enthought.scripting.api import stop_recording as stop
+    e = get_engine()
+    r = e.recorder
+    if r is not None:
+        stop(e, save=False)
+        if type(file) in types.StringTypes:
+            f = open(file, 'w')
+            r.save(f)
+            f.close()
+        elif hasattr(file, 'write') and hasattr(file, 'flush'):
+            r.save(file)
+
